@@ -12,7 +12,7 @@ class HltMkab(BaseModel):
     """
 
     id = models.AutoField(db_column="MKABID", primary_key=True)
-    uuid = models.CharField(db_column="UGUID", max_length=36, unique=True, default=uuid.uuid4)
+    uuid = models.CharField(db_column="UGUID", max_length=36, unique=True, default=uuid4)
     family = models.CharField(db_column="FAMILY", max_length=40)
     name = models.CharField(db_column="NAME", max_length=40)
     ot = models.CharField(db_column="OT", max_length=40)
